AuthResult<T> class

Constructors

AuthResult.failure(AuthException? error)
const
AuthResult.success(T? data)
const

Properties

data → T?
final
error AuthException?
final
hashCode int
The hash code for this object.
no setterinherited
isFailure bool
no setter
isSuccess bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fold<R>(R onSuccess(T data), R onFailure(AuthException error)) → R
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited