LoginCredentials class

Constructors

LoginCredentials({required String identifier, required String password, AuthMethod method = AuthMethod.email})
const

Properties

email String?
no setter
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
method AuthMethod
final
password String
final
phoneNumber String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited