RegisterCredentials class

Constructors

RegisterCredentials.email({required String? email, required String password, String? displayName})
const
RegisterCredentials.phone({required String? phoneNumber, required String password, String? displayName})
const

Properties

displayName → String?
final
email → String?
final
hashCode → int
The hash code for this object.
no setterinherited
method → AuthMethod
final
password → String
final
phoneNumber → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited