OtpModel class

Constructors

OtpModel({required String contact, required AuthMethod method, required String otp, DateTime? expiresAt, bool isVerified = false})
const

Properties

contact → String
final
expiresAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
isExpired → bool
no setter
isVerified → bool
final
method → AuthMethod
final
otp → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isVerified, DateTime? expiresAt}) → OtpModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited