UserModel class

Constructors

UserModel({required String uid, String? email, String? phoneNumber, String? displayName, String? photoUrl, bool isEmailVerified = false, bool isPhoneVerified = false, DateTime? createdAt, Map<String, dynamic>? metadata})
const
UserModel.fromMap(Map<String, dynamic> map)
factory

Properties

createdAt DateTime?
final
displayName String?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
isEmailVerified bool
final
isPhoneVerified bool
final
metadata Map<String, dynamic>?
final
phoneNumber String?
final
photoUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uid String
final

Methods

copyWith({String? uid, String? email, String? phoneNumber, String? displayName, String? photoUrl, bool? isEmailVerified, bool? isPhoneVerified, DateTime? createdAt, Map<String, dynamic>? metadata}) UserModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited