AuthProvider class

Inheritance

Constructors

AuthProvider(AuthService _authService)

Properties

error → AuthException?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isAuthenticated → bool
no setter
isLoading → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → AuthStatus
no setter
user → UserModel?
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearError() → void
dispose() → void
Discards any resources used by the object.
inherited
forgotPassword(String email) → Future<bool>
initialize() → Future<void>
login(LoginCredentials credentials) → Future<bool>
logout() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
register(RegisterCredentials credentials) → Future<bool>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resendOtp(String contact, AuthMethod method) → Future<bool>
resetPassword({required String token, required String newPassword}) → Future<bool>
sendOtp(String contact, AuthMethod method) → Future<bool>
toString() → String
A string representation of this object.
inherited
verifyOtp(String contact, String otp, AuthMethod method) → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited