PhoneAuthService class abstract

Constructors

PhoneAuthService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

loginWithPhone(String phoneNumber, String password) → Future<AuthResult<UserModel>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerWithPhone(String phoneNumber, String password, {String? displayName}) → Future<AuthResult<UserModel>>
resendPhoneOtp(String phoneNumber) → Future<AuthResult<void>>
sendPhoneOtp(String phoneNumber) → Future<AuthResult<void>>
toString() → String
A string representation of this object.
inherited
verifyPhoneOtp(String phoneNumber, String otp) → Future<AuthResult<bool>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited