AuthService class abstract

Implementers

Constructors

AuthService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forgotPassword(String email) Future<AuthResult<void>>
getCurrentUser() Future<AuthResult<UserModel?>>
login(LoginCredentials credentials) Future<AuthResult<UserModel>>
logout() Future<AuthResult<void>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(RegisterCredentials credentials) Future<AuthResult<UserModel>>
resendOtp(String contact, AuthMethod method) Future<AuthResult<void>>
resetPassword({required String token, required String newPassword}) Future<AuthResult<void>>
sendOtp(String contact, AuthMethod method) Future<AuthResult<void>>
toString() String
A string representation of this object.
inherited
updateProfile({String? displayName, String? photoUrl}) Future<AuthResult<UserModel>>
verifyOtp(String contact, String otp, AuthMethod method) Future<AuthResult<bool>>

Operators

operator ==(Object other) bool
The equality operator.
inherited