EmailAuthService class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
forgotPassword(
String email) → Future< AuthResult< void> > -
loginWithEmail(
String email, String password) → Future< AuthResult< UserModel> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerWithEmail(
String email, String password, {String? displayName}) → Future< AuthResult< UserModel> > -
resendEmailOtp(
String email) → Future< AuthResult< void> > -
resetPassword(
String token, String newPassword) → Future< AuthResult< void> > -
sendEmailOtp(
String email) → Future< AuthResult< void> > -
toString(
) → String -
A string representation of this object.
inherited
-
verifyEmailOtp(
String email, String otp) → Future< AuthResult< bool> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited