FirebaseAuthService class
- Inheritance
-
- Object
- AuthService
- FirebaseAuthService
Constructors
- FirebaseAuthService({FirebaseAuth? firebaseAuth})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
forgotPassword(
String email) → Future< AuthResult< void> > -
override
-
getCurrentUser(
) → Future< AuthResult< UserModel?> > -
override
-
login(
LoginCredentials credentials) → Future< AuthResult< UserModel> > -
override
-
logout(
) → Future< AuthResult< void> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
RegisterCredentials credentials) → Future< AuthResult< UserModel> > -
override
-
resendOtp(
String contact, AuthMethod method) → Future< AuthResult< void> > -
override
-
resetPassword(
{required String token, required String newPassword}) → Future< AuthResult< void> > -
override
-
sendOtp(
String contact, AuthMethod method) → Future< AuthResult< void> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateProfile(
{String? displayName, String? photoUrl}) → Future< AuthResult< UserModel> > -
override
-
verifyOtp(
String contact, String otp, AuthMethod method) → Future< AuthResult< bool> > -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited